#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements. See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership. The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License. You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.
#

import copy


def domain_socket_path(port):
    return '/tmp/v0.16/ThriftTest.thrift.%d' % port


def merge_dict(base, update):
    """Update dict concatenating list values"""
    res = copy.deepcopy(base)
    for k, v in list(update.items()):
        if k in list(res.keys()) and isinstance(v, list):
            res[k].extend(v)
        else:
            res[k] = v
    return res
